@@ -196,6 +196,7 @@ class TestSchema:
             "label_to_extend": "mylabel",
             "uses_extend_func": False,
         }
+        assert params.dump()["schema"]["operators"] == params.operators
 
         Params1.array_first = True
         params = Params1()
@@ -206,6 +207,7 @@ class TestSchema:
             "label_to_extend": "somelabel",
             "uses_extend_func": False,
         }
+        assert params.dump()["schema"]["operators"] == params.operators
 
         class Params2(Parameters):
             defaults = {"schema": {"operators": {"array_first": True}}}
@@ -218,6 +220,7 @@ class TestSchema:
             "label_to_extend": None,
             "uses_extend_func": False,
         }
+        assert params.dump()["schema"]["operators"] == params.operators
 
         class Params3(Parameters):
             array_first = True
@@ -230,6 +233,10 @@ class TestSchema:
             "label_to_extend": None,
             "uses_extend_func": False,
         }
+        assert params.dump()["schema"]["operators"] == params.operators
+
+        params.array_first = True
+        assert params.dump()["schema"]["operators"] == params.operators
 
     def test_when_schema(self):
         class Params(Parameters):
@@ -977,7 +984,7 @@ class TestValidationMessages:
         assert params.warnings
         assert not params.errors
 
-        msg = [f"int_warn_param -1 < min 0 "]
+        msg = ["int_warn_param -1 < min 0 "]
         assert (
             json.loads(excinfo.value.args[0])["warnings"]["int_warn_param"]
             == msg
